@@ -279,15 +279,13 @@ class LabelBase(Group):
         """Color of the background as an RGB hex number."""
         return self._background_color
 
+    def _set_background_color(self, new_color):
+        # subclasses should override this
+        pass
+
     @background_color.setter
     def background_color(self, new_color):
-        self._background_color = new_color
-        if new_color is not None:
-            self.palette[0] = new_color
-            self.palette.make_opaque(0)
-        else:
-            self.palette[0] = 0
-            self.palette.make_transparent(0)
+        self._set_background_color(new_color)
 
     @property
     def anchor_point(self):
